"""Constants for ThermiaGenesis integration."""
KEY_ATTRIBUTES = 'attributes'
KEY_ADDRESS = 'address'
KEY_RANGES = 'ranges'
KEY_SCALE = 'scale'
KEY_REG_TYPE = 'register_type'
KEY_BITS = 'bits'
KEY_DATATYPE = 'datatype'

TYPE_BIT = 'bit'
TYPE_INT = 'int'
TYPE_UINT = 'uint'
TYPE_LONG = 'long'
TYPE_STATUS = 'status'

REG_COIL = 'coil'
REG_DISCRETE_INPUT = 'dinput'
REG_INPUT = 'input'
REG_HOLDING = 'holding'
REG_TYPES = [REG_COIL, REG_DISCRETE_INPUT, REG_INPUT, REG_HOLDING]

DOMAIN = "thermiagenesis"

MODEL_MEGA = 'mega'
MODEL_INVERTER = 'inverter'

REGISTER_RANGES = {
    MODEL_MEGA: {
        REG_COIL: [[3, 28],[28, 59]],
        REG_DISCRETE_INPUT: [[0,3], [9, 83], [199, 247]],
        REG_INPUT: [[0, 100], [100, 174]],
        REG_HOLDING: [[0, 115], [116,116], [199, 217], [239, 257], [299, 321]],
    },
    MODEL_INVERTER: {
        #REG_COIL: [[3, 22],[23, 41]],
        #REG_DISCRETE_INPUT: [[0,3], [9, 45], [46, 83], [199, 247]],
        #REG_INPUT: [[0, 50], [51, 100], [100, 174]],
        #REG_HOLDING: [[0, 29], [30, 58], [59, 87], [88, 116], [199, 217], [239, 257], [299, 305]],
        REG_COIL: [[3, 41]],
        REG_DISCRETE_INPUT: [[0,3], [9, 45], [46, 83], [199, 247]],
        REG_INPUT: [[0, 174]],
        REG_HOLDING: [[0, 115],[116,116],[199, 217], [239, 257], [299, 305]],
    }
}

ATTR_COIL_RESET_ALL_ALARMS = "coil_reset_all_alarms"
ATTR_COIL_ENABLE_INTERNAL_ADDITIONAL_HEATER = "coil_enable_internal_additional_heater"
ATTR_COIL_ENABLE_EXTERNAL_ADDITIONAL_HEATER = "coil_enable_external_additional_heater"
ATTR_COIL_ENABLE_HGW = "coil_enable_hgw"
ATTR_COIL_ENABLE_FLOW_SWITCH_PRESSURE_SWITCH = "coil_enable_flow_switch_pressure_switch"
ATTR_COIL_ENABLE_TAP_WATER = "coil_enable_tap_water"
ATTR_COIL_ENABLE_HEAT = "coil_enable_heat"
ATTR_COIL_ENABLE_ACTIVE_COOLING = "coil_enable_active_cooling"
ATTR_COIL_ENABLE_MIX_VALVE_1 = "coil_enable_mix_valve_1"
ATTR_COIL_ENABLE_TWC = "coil_enable_twc"
ATTR_COIL_ENABLE_WCS = "coil_enable_wcs"
ATTR_COIL_ENABLE_HOT_GAS_PUMP = "coil_enable_hot_gas_pump"
ATTR_COIL_ENABLE_MIX_VALVE_2 = "coil_enable_mix_valve_2"
ATTR_COIL_ENABLE_MIX_VALVE_3 = "coil_enable_mix_valve_3"
ATTR_COIL_ENABLE_MIX_VALVE_4 = "coil_enable_mix_valve_4"
ATTR_COIL_ENABLE_MIX_VALVE_5 = "coil_enable_mix_valve_5"
ATTR_COIL_ENABLE_BRINE_OUT_MONITORING = "coil_enable_brine_out_monitoring"
ATTR_COIL_ENABLE_BRINE_PUMP_CONTINUOUS_OPERATION = "coil_enable_brine_pump_continuous_operation"
ATTR_COIL_ENABLE_SYSTEM_CIRCULATION_PUMP = "coil_enable_system_circulation_pump"
ATTR_COIL_ENABLE_DEW_POINT_CALCULATION = "coil_enable_dew_point_calculation"
ATTR_COIL_ENABLE_ANTI_LEGIONELLA = "coil_enable_anti_legionella"
ATTR_COIL_ENABLE_ADDITIONAL_HEATER_ONLY = "coil_enable_additional_heater_only"
ATTR_COIL_ENABLE_CURRENT_LIMITATION = "coil_enable_current_limitation"
ATTR_COIL_ENABLE_POOL = "coil_enable_pool"
ATTR_COIL_ENABLE_SURPLUS_HEAT_CHILLER = "coil_enable_surplus_heat_chiller"
ATTR_COIL_ENABLE_SURPLUS_HEAT_BOREHOLE = "coil_enable_surplus_heat_borehole"
ATTR_COIL_ENABLE_EXTERNAL_ADDITIONAL_HEATER_FOR_POOL = "coil_enable_external_additional_heater_for_pool"
ATTR_COIL_ENABLE_INTERNAL_ADDITIONAL_HEATER_FOR_POOL = "coil_enable_internal_additional_heater_for_pool"
ATTR_COIL_ENABLE_PASSIVE_COOLING = "coil_enable_passive_cooling"
ATTR_COIL_ENABLE_VARIABLE_SPEED_MODE_FOR_CONDENSER_PUMP = "coil_enable_variable_speed_mode_for_condenser_pump"
ATTR_COIL_ENABLE_VARIABLE_SPEED_MODE_FOR_BRINE_PUMP = "coil_enable_variable_speed_mode_for_brine_pump"
ATTR_COIL_ENABLE_COOLING_MODE_FOR_MIXING_VALVE_1 = "coil_enable_cooling_mode_for_mixing_valve_1"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_1 = "coil_enable_outdoor_temp_dependent_for_cooling_with_mixing_valve_1"
ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_1 = "coil_enable_internal_brine_pump_to_start_when_cooling_is_active_for_mixing_valve_1"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_EXTERNAL_HEATER = "coil_enable_outdoor_temp_dependent_for_external_heater"
ATTR_COIL_ENABLE_BRINE_IN_MONITORING = "coil_enable_brine_in_monitoring"
ATTR_COIL_ENABLE_FIXED_SYSTEM_SUPPLY_SET_POINT = "coil_enable_fixed_system_supply_set_point"
ATTR_COIL_ENABLE_EVAPORATOR_FREEZE_PROTECTION = "coil_enable_evaporator_freeze_protection"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_2 = "coil_enable_outdoor_temp_dependent_for_cooling_with_mixing_valve_2"
ATTR_COIL_ENABLE_DEW_POINT_CALCULATION_ON_MIXING_VALVE_2 = "coil_enable_dew_point_calculation_on_mixing_valve_2"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_HEATING_WITH_MIXING_VALVE_2 = "coil_enable_outdoor_temp_dependent_for_heating_with_mixing_valve_2"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_3 = "coil_enable_outdoor_temp_dependent_for_cooling_with_mixing_valve_3"
ATTR_COIL_ENABLE_DEW_POINT_CALCULATION_ON_MIXING_VALVE_3 = "coil_enable_dew_point_calculation_on_mixing_valve_3"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_HEATING_WITH_MIXING_VALVE_3 = "coil_enable_outdoor_temp_dependent_for_heating_with_mixing_valve_3"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_4 = "coil_enable_outdoor_temp_dependent_for_cooling_with_mixing_valve_4"
ATTR_COIL_ENABLE_DEW_POINT_CALCULATION_ON_MIXING_VALVE_4 = "coil_enable_dew_point_calculation_on_mixing_valve_4"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_HEATING_WITH_MIXING_VALVE_4 = "coil_enable_outdoor_temp_dependent_for_heating_with_mixing_valve_4"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_5 = "coil_enable_outdoor_temp_dependent_for_cooling_with_mixing_valve_5"
ATTR_COIL_ENABLE_DEW_POINT_CALCULATION_ON_MIXING_VALVE_5 = "coil_enable_dew_point_calculation_on_mixing_valve_5"
ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_HEATING_WITH_MIXING_VALVE_5 = "coil_enable_outdoor_temp_dependent_for_heating_with_mixing_valve_5"
ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_2 = "coil_enable_internal_brine_pump_to_start_when_cooling_is_active_for_mixing_valve_2"
ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_3 = "coil_enable_internal_brine_pump_to_start_when_cooling_is_active_for_mixing_valve_3"
ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_4 = "coil_enable_internal_brine_pump_to_start_when_cooling_is_active_for_mixing_valve_4"
ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_5 = "coil_enable_internal_brine_pump_to_start_when_cooling_is_active_for_mixing_valve_5"
ATTR_DINPUT_ALARM_ACTIVE_CLASS_A = "dinput_alarm_active_class_a"
ATTR_DINPUT_ALARM_ACTIVE_CLASS_B = "dinput_alarm_active_class_b"
ATTR_DINPUT_ALARM_ACTIVE_CLASS_C = "dinput_alarm_active_class_c"
ATTR_DINPUT_ALARM_ACTIVE_CLASS_D = "dinput_alarm_active_class_d"
ATTR_DINPUT_ALARM_ACTIVE_CLASS_E = "dinput_alarm_active_class_e"
ATTR_DINPUT_HIGH_PRESSURE_SWITCH_ALARM = "dinput_high_pressure_switch_alarm"
ATTR_DINPUT_LOW_PRESSURE_LEVEL_ALARM = "dinput_low_pressure_level_alarm"
ATTR_DINPUT_HIGH_DISCHARGE_PIPE_TEMPERATURE_ALARM = "dinput_high_discharge_pipe_temperature_alarm"
ATTR_DINPUT_OPERATING_PRESSURE_LIMIT_INDICATION = "dinput_operating_pressure_limit_indication"
ATTR_DINPUT_DISCHARGE_PIPE_SENSOR_ALARM = "dinput_discharge_pipe_sensor_alarm"
ATTR_DINPUT_LIQUID_LINE_SENSOR_ALARM = "dinput_liquid_line_sensor_alarm"
ATTR_DINPUT_SUCTION_GAS_SENSOR_ALARM = "dinput_suction_gas_sensor_alarm"
ATTR_DINPUT_FLOW_PRESSURE_SWITCH_ALARM = "dinput_flow_pressure_switch_alarm"
ATTR_DINPUT_POWER_INPUT_PHASE_DETECTION_ALARM = "dinput_power_input_phase_detection_alarm"
ATTR_DINPUT_INVERTER_UNIT_ALARM = "dinput_inverter_unit_alarm"
ATTR_DINPUT_SYSTEM_SUPPLY_LOW_TEMPERATURE_ALARM = "dinput_system_supply_low_temperature_alarm"
ATTR_DINPUT_COMPRESSOR_LOW_SPEED_ALARM = "dinput_compressor_low_speed_alarm"
ATTR_DINPUT_LOW_SUPER_HEAT_ALARM = "dinput_low_super_heat_alarm"
ATTR_DINPUT_PRESSURE_RATIO_OUT_OF_RANGE_ALARM = "dinput_pressure_ratio_out_of_range_alarm"
ATTR_DINPUT_COMPRESSOR_PRESSURE_OUTSIDE_ENVELOPE_ALARM = "dinput_compressor_pressure_outside_envelope_alarm"
ATTR_DINPUT_BRINE_TEMPERATURE_OUT_OF_RANGE_ALARM = "dinput_brine_temperature_out_of_range_alarm"
ATTR_DINPUT_BRINE_IN_SENSOR_ALARM = "dinput_brine_in_sensor_alarm"
ATTR_DINPUT_BRINE_OUT_SENSOR_ALARM = "dinput_brine_out_sensor_alarm"
ATTR_DINPUT_CONDENSER_IN_SENSOR_ALARM = "dinput_condenser_in_sensor_alarm"
ATTR_DINPUT_CONDENSER_OUT_SENSOR_ALARM = "dinput_condenser_out_sensor_alarm"
ATTR_DINPUT_OUTDOOR_SENSOR_ALARM = "dinput_outdoor_sensor_alarm"
ATTR_DINPUT_SYSTEM_SUPPLY_LINE_SENSOR_ALARM = "dinput_system_supply_line_sensor_alarm"
ATTR_DINPUT_MIX_VALVE_1_SUPPLY_LINE_SENSOR_ALARM = "dinput_mix_valve_1_supply_line_sensor_alarm"
ATTR_DINPUT_MIX_VALVE_2_SUPPLY_LINE_SENSOR_ALARM = "dinput_mix_valve_2_supply_line_sensor_alarm"
ATTR_DINPUT_MIX_VALVE_3_SUPPLY_LINE_SENSOR_ALARM = "dinput_mix_valve_3_supply_line_sensor_alarm"
ATTR_DINPUT_MIX_VALVE_4_SUPPLY_LINE_SENSOR_ALARM = "dinput_mix_valve_4_supply_line_sensor_alarm"
ATTR_DINPUT_MIX_VALVE_5_SUPPLY_LINE_SENSOR_ALARM = "dinput_mix_valve_5_supply_line_sensor_alarm"
ATTR_DINPUT_WCS_RETURN_LINE_SENSOR_ALARM = "dinput_wcs_return_line_sensor_alarm"
ATTR_DINPUT_TWC_SUPPLY_LINE_SENSOR_ALARM = "dinput_twc_supply_line_sensor_alarm"
ATTR_DINPUT_COOLING_TANK_SENSOR_ALARM = "dinput_cooling_tank_sensor_alarm"
ATTR_DINPUT_COOLING_SUPPLY_LINE_SENSOR_ALARM = "dinput_cooling_supply_line_sensor_alarm"
ATTR_DINPUT_COOLING_CIRCUIT_RETURN_LINE_SENSOR_ALARM = "dinput_cooling_circuit_return_line_sensor_alarm"
ATTR_DINPUT_BRINE_DELTA_OUT_OF_RANGE_ALARM = "dinput_brine_delta_out_of_range_alarm"
ATTR_DINPUT_TAP_WATER_MID_SENSOR_ALARM = "dinput_tap_water_mid_sensor_alarm"
ATTR_DINPUT_TWC_CIRCULATION_RETURN_SENSOR_ALARM = "dinput_twc_circulation_return_sensor_alarm"
ATTR_DINPUT_HGW_SENSOR_ALARM = "dinput_hgw_sensor_alarm"
ATTR_DINPUT_INTERNAL_ADDITIONAL_HEATER_ALARM = "dinput_internal_additional_heater_alarm"
ATTR_DINPUT_BRINE_IN_HIGH_TEMPERATURE_ALARM = "dinput_brine_in_high_temperature_alarm"
ATTR_DINPUT_BRINE_IN_LOW_TEMPERATURE_ALARM = "dinput_brine_in_low_temperature_alarm"
ATTR_DINPUT_BRINE_OUT_LOW_TEMPERATURE_ALARM = "dinput_brine_out_low_temperature_alarm"
ATTR_DINPUT_TWC_CIRCULATION_RETURN_LOW_TEMPERATURE_ALARM = "dinput_twc_circulation_return_low_temperature_alarm"
ATTR_DINPUT_TWC_SUPPLY_LOW_TEMPERATURE_ALARM = "dinput_twc_supply_low_temperature_alarm"
ATTR_DINPUT_MIX_VALVE_1_SUPPLY_TEMPERATURE_DEVIATION_ALARM = "dinput_mix_valve_1_supply_temperature_deviation_alarm"
ATTR_DINPUT_MIX_VALVE_2_SUPPLY_TEMPERATURE_DEVIATION_ALARM = "dinput_mix_valve_2_supply_temperature_deviation_alarm"
ATTR_DINPUT_MIX_VALVE_3_SUPPLY_TEMPERATURE_DEVIATION_ALARM = "dinput_mix_valve_3_supply_temperature_deviation_alarm"
ATTR_DINPUT_MIX_VALVE_4_SUPPLY_TEMPERATURE_DEVIATION_ALARM = "dinput_mix_valve_4_supply_temperature_deviation_alarm"
ATTR_DINPUT_MIX_VALVE_5_SUPPLY_TEMPERATURE_DEVIATION_ALARM = "dinput_mix_valve_5_supply_temperature_deviation_alarm"
ATTR_DINPUT_WCS_RETURN_LINE_TEMPERATURE_DEVIATION_ALARM = "dinput_wcs_return_line_temperature_deviation_alarm"
ATTR_DINPUT_SUM_ALARM = "dinput_sum_alarm"
ATTR_DINPUT_COOLING_CIRCUIT_SUPPLY_LINE_TEMPERATURE_DEVIATION_ALARM = "dinput_cooling_circuit_supply_line_temperature_deviation_alarm"
ATTR_DINPUT_COOLING_TANK_TEMPERATURE_DEVIATION_ALARM = "dinput_cooling_tank_temperature_deviation_alarm"
ATTR_DINPUT_SURPLUS_HEAT_TEMPERATURE_DEVIATION_ALARM = "dinput_surplus_heat_temperature_deviation_alarm"
ATTR_DINPUT_HUMIDITY_ROOM_SENSOR_ALARM = "dinput_humidity_room_sensor_alarm"
ATTR_DINPUT_SURPLUS_HEAT_SUPPLY_LINE_SENSOR_ALARM = "dinput_surplus_heat_supply_line_sensor_alarm"
ATTR_DINPUT_SURPLUS_HEAT_RETURN_LINE_SENSOR_ALARM = "dinput_surplus_heat_return_line_sensor_alarm"
ATTR_DINPUT_COOLING_TANK_RETURN_LINE_SENSOR_ALARM = "dinput_cooling_tank_return_line_sensor_alarm"
ATTR_DINPUT_TEMPERATURE_ROOM_SENSOR_ALARM = "dinput_temperature_room_sensor_alarm"
ATTR_DINPUT_INVERTER_UNIT_COMMUNICATION_ALARM = "dinput_inverter_unit_communication_alarm"
ATTR_DINPUT_POOL_RETURN_LINE_SENSOR_ALARM = "dinput_pool_return_line_sensor_alarm"
ATTR_DINPUT_EXTERNAL_STOP_FOR_POOL = "dinput_external_stop_for_pool"
ATTR_DINPUT_EXTERNAL_START_BRINE_PUMP = "dinput_external_start_brine_pump"
ATTR_DINPUT_EXTERNAL_RELAY_FOR_BRINE_GROUND_WATER_PUMP = "dinput_external_relay_for_brine_ground_water_pump"
ATTR_DINPUT_TAP_WATER_END_TANK_SENSOR_ALARM = "dinput_tap_water_end_tank_sensor_alarm"
ATTR_DINPUT_MAXIMUM_TIME_FOR_ANTI_LEGIONELLA_EXCEEDED_ALARM = "dinput_maximum_time_for_anti_legionella_exceeded_alarm"
ATTR_DINPUT_GENESIS_SECONDARY_UNIT_ALARM = "dinput_genesis_secondary_unit_alarm"
ATTR_DINPUT_PRIMARY_UNIT_CONFLICT_ALARM = "dinput_primary_unit_conflict_alarm"
ATTR_DINPUT_PRIMARY_UNIT_NO_SECONDARY_ALARM = "dinput_primary_unit_no_secondary_alarm"
ATTR_DINPUT_OIL_BOOST_IN_PROGRESS = "dinput_oil_boost_in_progress"
ATTR_DINPUT_COMPRESSOR_CONTROL_SIGNAL = "dinput_compressor_control_signal"
ATTR_DINPUT_SMART_GRID_1 = "dinput_smart_grid_1"
ATTR_DINPUT_EXTERNAL_ALARM_INPUT = "dinput_external_alarm_input"
ATTR_DINPUT_SMART_GRID_2 = "dinput_smart_grid_2"
ATTR_DINPUT_EXTERNAL_ADDITIONAL_HEATER_CONTROL_SIGNAL = "dinput_external_additional_heater_control_signal"
ATTR_DINPUT_MIX_VALVE_1_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_mix_valve_1_circulation_pump_control_signal"
ATTR_DINPUT_CONDENSER_PUMP_ON_OFF_CONTROL = "dinput_condenser_pump_on_off_control"
ATTR_DINPUT_SYSTEM_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_system_circulation_pump_control_signal"
ATTR_DINPUT_HOT_GAS_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_hot_gas_circulation_pump_control_signal"
ATTR_DINPUT_BRINE_PUMP_ON_OFF_CONTROL = "dinput_brine_pump_on_off_control"
ATTR_DINPUT_EXTERNAL_HEATER_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_external_heater_circulation_pump_control_signal"
ATTR_DINPUT_HEATING_SEASON_ACTIVE = "dinput_heating_season_active"
ATTR_DINPUT_EXTERNAL_ADDITIONAL_HEATER_ACTIVE = "dinput_external_additional_heater_active"
ATTR_DINPUT_INTERNAL_ADDITIONAL_HEATER_ACTIVE = "dinput_internal_additional_heater_active"
ATTR_DINPUT_HGW_REGULATION_CONTROL_SIGNAL = "dinput_hgw_regulation_control_signal"
ATTR_DINPUT_HEAT_PUMP_STOPPING = "dinput_heat_pump_stopping"
ATTR_DINPUT_HEAT_PUMP_OK_TO_START = "dinput_heat_pump_ok_to_start"
ATTR_DINPUT_TWC_SUPPLY_LINE_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_twc_supply_line_circulation_pump_control_signal"
ATTR_DINPUT_WCS_REGULATION_CONTROL_SIGNAL = "dinput_wcs_regulation_control_signal"
ATTR_DINPUT_WCS_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_wcs_circulation_pump_control_signal"
ATTR_DINPUT_TWC_END_TANK_HEATER_CONTROL_SIGNAL = "dinput_twc_end_tank_heater_control_signal"
ATTR_DINPUT_POOL_DIRECTIONAL_VALVE_POSITION = "dinput_pool_directional_valve_position"
ATTR_DINPUT_COOLING_CIRCUIT_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_cooling_circuit_circulation_pump_control_signal"
ATTR_DINPUT_POOL_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_pool_circulation_pump_control_signal"
ATTR_DINPUT_SURPLUS_HEAT_DIRECTIONAL_VALVE_POSITION = "dinput_surplus_heat_directional_valve_position"
ATTR_DINPUT_SURPLUS_HEAT_CIRCULATION_PUMP_CONTROL_SIGNAL = "dinput_surplus_heat_circulation_pump_control_signal"
ATTR_DINPUT_COOLING_CIRCUIT_REGULATION_CONTROL_SIGNAL = "dinput_cooling_circuit_regulation_control_signal"
ATTR_DINPUT_SURPLUS_HEAT_REGULATION_CONTROL_SIGNAL = "dinput_surplus_heat_regulation_control_signal"
ATTR_DINPUT_ACTIVE_COOLING_DIRECTIONAL_VALVE_POSITION = "dinput_active_cooling_directional_valve_position"
ATTR_DINPUT_PASSIVE_ACTIVE_COOLING_DIRECTIONAL_VALVE_POSITION = "dinput_passive_active_cooling_directional_valve_position"
ATTR_DINPUT_POOL_REGULATION_CONTROL_SIGNAL = "dinput_pool_regulation_control_signal"
ATTR_DINPUT_INDICATION_WHEN_MIXING_VALVE_1_IS_PRODUCING_PASSIVE_COOLING = "dinput_indication_when_mixing_valve_1_is_producing_passive_cooling"
ATTR_DINPUT_COMPRESSOR_IS_UNABLE_TO_SPEED_UP = "dinput_compressor_is_unable_to_speed_up"
ATTR_INPUT_FIRST_PRIORITISED_DEMAND = "input_first_prioritised_demand"
ATTR_INPUT_COMPRESSOR_AVAILABLE_GEARS = "input_compressor_available_gears"
ATTR_INPUT_COMPRESSOR_SPEED_RPM = "input_compressor_speed_rpm"
ATTR_INPUT_EXTERNAL_ADDITIONAL_HEATER_CURRENT_DEMAND = "input_external_additional_heater_current_demand"
ATTR_INPUT_DISCHARGE_PIPE_TEMPERATURE = "input_discharge_pipe_temperature"
ATTR_INPUT_CONDENSER_IN_TEMPERATURE = "input_condenser_in_temperature"
ATTR_INPUT_CONDENSER_OUT_TEMPERATURE = "input_condenser_out_temperature"
ATTR_INPUT_BRINE_IN_TEMPERATURE = "input_brine_in_temperature"
ATTR_INPUT_BRINE_OUT_TEMPERATURE = "input_brine_out_temperature"
ATTR_INPUT_SYSTEM_SUPPLY_LINE_TEMPERATURE = "input_system_supply_line_temperature"
ATTR_INPUT_OUTDOOR_TEMPERATURE = "input_outdoor_temperature"
ATTR_INPUT_TAP_WATER_TOP_TEMPERATURE = "input_tap_water_top_temperature"
ATTR_INPUT_TAP_WATER_LOWER_TEMPERATURE = "input_tap_water_lower_temperature"
ATTR_INPUT_TAP_WATER_WEIGHTED_TEMPERATURE = "input_tap_water_weighted_temperature"
ATTR_INPUT_SYSTEM_SUPPLY_LINE_CALCULATED_SET_POINT = "input_system_supply_line_calculated_set_point"
ATTR_INPUT_SELECTED_HEAT_CURVE = "input_selected_heat_curve"
ATTR_INPUT_HEAT_CURVE_X_COORDINATE_1 = "input_heat_curve_x_coordinate_1"
ATTR_INPUT_HEAT_CURVE_X_COORDINATE_2 = "input_heat_curve_x_coordinate_2"
ATTR_INPUT_HEAT_CURVE_X_COORDINATE_3 = "input_heat_curve_x_coordinate_3"
ATTR_INPUT_HEAT_CURVE_X_COORDINATE_4 = "input_heat_curve_x_coordinate_4"
ATTR_INPUT_HEAT_CURVE_X_COORDINATE_5 = "input_heat_curve_x_coordinate_5"
ATTR_INPUT_HEAT_CURVE_X_COORDINATE_6 = "input_heat_curve_x_coordinate_6"
ATTR_INPUT_HEAT_CURVE_X_COORDINATE_7 = "input_heat_curve_x_coordinate_7"
ATTR_INPUT_COOLING_SEASON_INTEGRAL_VALUE = "input_cooling_season_integral_value"
ATTR_INPUT_CONDENSER_CIRCULATION_PUMP_SPEED = "input_condenser_circulation_pump_speed"
ATTR_INPUT_MIX_VALVE_1_SUPPLY_LINE_TEMPERATURE = "input_mix_valve_1_supply_line_temperature"
ATTR_INPUT_BUFFER_TANK_TEMPERATURE = "input_buffer_tank_temperature"
ATTR_INPUT_MIX_VALVE_1_POSITION = "input_mix_valve_1_position"
ATTR_INPUT_BRINE_CIRCULATION_PUMP_SPEED = "input_brine_circulation_pump_speed"
ATTR_INPUT_HGW_SUPPLY_LINE_TEMPERATURE = "input_hgw_supply_line_temperature"
ATTR_INPUT_HOT_WATER_DIRECTIONAL_VALVE_POSITION = "input_hot_water_directional_valve_position"
ATTR_INPUT_COMPRESSOR_OPERATING_HOURS = "input_compressor_operating_hours"
ATTR_INPUT_TAP_WATER_OPERATING_HOURS = "input_tap_water_operating_hours"
ATTR_INPUT_EXTERNAL_ADDITIONAL_HEATER_OPERATING_HOURS = "input_external_additional_heater_operating_hours"
ATTR_INPUT_COMPRESSOR_SPEED_PERCENT = "input_compressor_speed_percent"
ATTR_INPUT_SECOND_PRIORITISED_DEMAND = "input_second_prioritised_demand"
ATTR_INPUT_THIRD_PRIORITISED_DEMAND = "input_third_prioritised_demand"
ATTR_INPUT_SOFTWARE_VERSION_MAJOR = "input_software_version_major"
ATTR_INPUT_SOFTWARE_VERSION_MINOR = "input_software_version_minor"
ATTR_INPUT_SOFTWARE_VERSION_MICRO = "input_software_version_micro"
ATTR_INPUT_COMPRESSOR_TEMPORARILY_BLOCKED = "input_compressor_temporarily_blocked"
ATTR_INPUT_COMPRESSOR_CURRENT_GEAR = "input_compressor_current_gear"
ATTR_INPUT_QUEUED_DEMAND_FIRST_PRIORITY = "input_queued_demand_first_priority"
ATTR_INPUT_QUEUED_DEMAND_SECOND_PRIORITY = "input_queued_demand_second_priority"
ATTR_INPUT_QUEUED_DEMAND_THIRD_PRIORITY = "input_queued_demand_third_priority"
ATTR_INPUT_QUEUED_DEMAND_FOURTH_PRIORITY = "input_queued_demand_fourth_priority"
ATTR_INPUT_QUEUED_DEMAND_FIFTH_PRIORITY = "input_queued_demand_fifth_priority"
ATTR_INPUT_INTERNAL_ADDITIONAL_HEATER_CURRENT_STEP = "input_internal_additional_heater_current_step"
ATTR_INPUT_BUFFER_TANK_CHARGE_SET_POINT = "input_buffer_tank_charge_set_point"
ATTR_INPUT_ELECTRIC_METER_L1_CURRENT = "input_electric_meter_l1_current"
ATTR_INPUT_ELECTRIC_METER_L2_CURRENT = "input_electric_meter_l2_current"
ATTR_INPUT_ELECTRIC_METER_L3_CURRENT = "input_electric_meter_l3_current"
ATTR_INPUT_ELECTRIC_METER_L1_0_VOLTAGE = "input_electric_meter_l1_0_voltage"
ATTR_INPUT_ELECTRIC_METER_L2_0_VOLTAGE = "input_electric_meter_l2_0_voltage"
ATTR_INPUT_ELECTRIC_METER_L3_0_VOLTAGE = "input_electric_meter_l3_0_voltage"
ATTR_INPUT_ELECTRIC_METER_L1_L2_VOLTAGE = "input_electric_meter_l1_l2_voltage"
ATTR_INPUT_ELECTRIC_METER_L2_L3_VOLTAGE = "input_electric_meter_l2_l3_voltage"
ATTR_INPUT_ELECTRIC_METER_L3_L1_VOLTAGE = "input_electric_meter_l3_l1_voltage"
ATTR_INPUT_ELECTRIC_METER_L1_POWER = "input_electric_meter_l1_power"
ATTR_INPUT_ELECTRIC_METER_L2_POWER = "input_electric_meter_l2_power"
ATTR_INPUT_ELECTRIC_METER_L3_POWER = "input_electric_meter_l3_power"
ATTR_INPUT_ELECTRIC_METER_METER_VALUE = "input_electric_meter_meter_value"
ATTR_INPUT_COMFORT_MODE = "input_comfort_mode"
ATTR_INPUT_ELECTRIC_METER_KWH_TOTAL = "input_electric_meter_kwh_total"
ATTR_INPUT_WCS_VALVE_POSITION = "input_wcs_valve_position"
ATTR_INPUT_TWC_VALVE_POSITION = "input_twc_valve_position"
ATTR_INPUT_MIX_VALVE_2_POSITION = "input_mix_valve_2_position"
ATTR_INPUT_MIX_VALVE_3_POSITION = "input_mix_valve_3_position"
ATTR_INPUT_MIX_VALVE_4_POSITION = "input_mix_valve_4_position"
ATTR_INPUT_MIX_VALVE_5_POSITION = "input_mix_valve_5_position"
ATTR_INPUT_DEW_POINT_ROOM = "input_dew_point_room"
ATTR_INPUT_COOLING_SUPPLY_LINE_MIX_VALVE_POSITION = "input_cooling_supply_line_mix_valve_position"
ATTR_INPUT_SURPLUS_HEAT_FAN_SPEED = "input_surplus_heat_fan_speed"
ATTR_INPUT_POOL_SUPPLY_LINE_MIX_VALVE_POSITION = "input_pool_supply_line_mix_valve_position"
ATTR_INPUT_TWC_SUPPLY_LINE_TEMPERATURE = "input_twc_supply_line_temperature"
ATTR_INPUT_TWC_RETURN_TEMPERATURE = "input_twc_return_temperature"
ATTR_INPUT_WCS_RETURN_LINE_TEMPERATURE = "input_wcs_return_line_temperature"
ATTR_INPUT_TWC_END_TANK_TEMPERATURE = "input_twc_end_tank_temperature"
ATTR_INPUT_MIX_VALVE_2_SUPPLY_LINE_TEMPERATURE = "input_mix_valve_2_supply_line_temperature"
ATTR_INPUT_MIX_VALVE_3_SUPPLY_LINE_TEMPERATURE = "input_mix_valve_3_supply_line_temperature"
ATTR_INPUT_MIX_VALVE_4_SUPPLY_LINE_TEMPERATURE = "input_mix_valve_4_supply_line_temperature"
ATTR_INPUT_COOLING_CIRCUIT_RETURN_LINE_TEMPERATURE = "input_cooling_circuit_return_line_temperature"
ATTR_INPUT_COOLING_TANK_TEMPERATURE = "input_cooling_tank_temperature"
ATTR_INPUT_COOLING_TANK_RETURN_LINE_TEMPERATURE = "input_cooling_tank_return_line_temperature"
ATTR_INPUT_COOLING_CIRCUIT_SUPPLY_LINE_TEMPERATURE = "input_cooling_circuit_supply_line_temperature"
ATTR_INPUT_MIX_VALVE_5_SUPPLY_LINE_TEMPERATURE = "input_mix_valve_5_supply_line_temperature"
ATTR_INPUT_MIX_VALVE_2_RETURN_LINE_TEMPERATURE = "input_mix_valve_2_return_line_temperature"
ATTR_INPUT_MIX_VALVE_3_RETURN_LINE_TEMPERATURE = "input_mix_valve_3_return_line_temperature"
ATTR_INPUT_MIX_VALVE_4_RETURN_LINE_TEMPERATURE = "input_mix_valve_4_return_line_temperature"
ATTR_INPUT_MIX_VALVE_5_RETURN_LINE_TEMPERATURE = "input_mix_valve_5_return_line_temperature"
ATTR_INPUT_SURPLUS_HEAT_RETURN_LINE_TEMPERATURE = "input_surplus_heat_return_line_temperature"
ATTR_INPUT_SURPLUS_HEAT_SUPPLY_LINE_TEMPERATURE = "input_surplus_heat_supply_line_temperature"
ATTR_INPUT_POOL_SUPPLY_LINE_TEMPERATURE = "input_pool_supply_line_temperature"
ATTR_INPUT_POOL_RETURN_LINE_TEMPERATURE = "input_pool_return_line_temperature"
ATTR_INPUT_ROOM_TEMPERATURE_SENSOR = "input_room_temperature_sensor"
ATTR_INPUT_BUBBLE_POINT = "input_bubble_point"
ATTR_INPUT_DEW_POINT = "input_dew_point"
ATTR_INPUT_DEW_POINT = "input_dew_point"
ATTR_INPUT_SUPERHEAT_TEMPERATURE = "input_superheat_temperature"
ATTR_INPUT_SUB_COOLING_TEMPERATURE = "input_sub_cooling_temperature"
ATTR_INPUT_LOW_PRESSURE_SIDE = "input_low_pressure_side"
ATTR_INPUT_HIGH_PRESSURE_SIDE = "input_high_pressure_side"
ATTR_INPUT_LIQUID_LINE_TEMPERATURE = "input_liquid_line_temperature"
ATTR_INPUT_SUCTION_GAS_TEMPERATURE = "input_suction_gas_temperature"
ATTR_INPUT_HEATING_SEASON_INTEGRAL_VALUE = "input_heating_season_integral_value"
ATTR_INPUT_P_VALUE_FOR_GEAR_SHIFTING_AND_DEMAND_CALCULATION = "input_p_value_for_gear_shifting_and_demand_calculation"
ATTR_INPUT_I_VALUE_FOR_GEAR_SHIFTING_AND_DEMAND_CALCULATION = "input_i_value_for_gear_shifting_and_demand_calculation"
ATTR_INPUT_D_VALUE_FOR_GEAR_SHIFTING_AND_DEMAND_CALCULATION = "input_d_value_for_gear_shifting_and_demand_calculation"
ATTR_INPUT_I_VALUE_FOR_COMPRESSOR_ON_OFF_BUFFER_TANK = "input_i_value_for_compressor_on_off_buffer_tank"
ATTR_INPUT_P_VALUE_FOR_COMPRESSOR_ON_OFF_BUFFER_TANK = "input_p_value_for_compressor_on_off_buffer_tank"
ATTR_INPUT_MIX_VALVE_COOLING_OPENING_DEGREE = "input_mix_valve_cooling_opening_degree"
ATTR_INPUT_DESIRED_GEAR_FOR_TAP_WATER = "input_desired_gear_for_tap_water"
ATTR_INPUT_DESIRED_GEAR_FOR_HEATING = "input_desired_gear_for_heating"
ATTR_INPUT_DESIRED_GEAR_FOR_COOLING = "input_desired_gear_for_cooling"
ATTR_INPUT_DESIRED_GEAR_FOR_POOL = "input_desired_gear_for_pool"
ATTR_INPUT_NUMBER_OF_AVAILABLE_SECONDARIES_GENESIS = "input_number_of_available_secondaries_genesis"
ATTR_INPUT_NUMBER_OF_AVAILABLE_SECONDARIES_LEGACY = "input_number_of_available_secondaries_legacy"
ATTR_INPUT_TOTAL_DISTRIBUTED_GEARS_TO_ALL_UNITS = "input_total_distributed_gears_to_all_units"
ATTR_INPUT_MAXIMUM_GEAR_OUT_OF_ALL_THE_CURRENTLY_REQUESTED_GEARS = "input_maximum_gear_out_of_all_the_currently_requested_gears"
ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_1 = "input_desired_temperature_distribution_circuit_mix_valve_1"
ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_2 = "input_desired_temperature_distribution_circuit_mix_valve_2"
ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_3 = "input_desired_temperature_distribution_circuit_mix_valve_3"
ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_4 = "input_desired_temperature_distribution_circuit_mix_valve_4"
ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_5 = "input_desired_temperature_distribution_circuit_mix_valve_5"
ATTR_INPUT_DISCONNECT_HOT_GAS_END_TANK = "input_disconnect_hot_gas_end_tank"
ATTR_INPUT_LEGACY_HEAT_PUMP_COMPRESSOR_RUNNING = "input_legacy_heat_pump_compressor_running"
ATTR_INPUT_LEGACY_HEAT_PUMP_REPORTING_ALARM = "input_legacy_heat_pump_reporting_alarm"
ATTR_INPUT_LEGACY_HEAT_PUMP_START_SIGNAL = "input_legacy_heat_pump_start_signal"
ATTR_INPUT_LEGACY_HEAT_PUMP_TAP_WATER_SIGNAL = "input_legacy_heat_pump_tap_water_signal"
ATTR_INPUT_PRIMARY_UNIT_ALARM_COMBINED_OUTPUT_OF_ALL_CLASS_D_ALARMS = "input_primary_unit_alarm_combined_output_of_all_class_d_alarms"
ATTR_INPUT_PRIMARY_UNIT_ALARM_PRIMARY_UNIT_HAS_LOST_COMMUNICATION = "input_primary_unit_alarm_primary_unit_has_lost_communication"
ATTR_INPUT_PRIMARY_UNIT_ALARM_CLASS_A_ALARM_DETECTED_ON_THE_GENESIS_SECONDARY = "input_primary_unit_alarm_class_a_alarm_detected_on_the_genesis_secondary"
ATTR_INPUT_PRIMARY_UNIT_ALARM_CLASS_B_ALARM_DETECTED_ON_THE_GENESIS_SECONDARY = "input_primary_unit_alarm_class_b_alarm_detected_on_the_genesis_secondary"
ATTR_INPUT_PRIMARY_UNIT_ALARM_COMBINED_OUTPUT_OF_ALL_CLASS_E_ALARMS = "input_primary_unit_alarm_combined_output_of_all_class_e_alarms"
ATTR_INPUT_PRIMARY_UNIT_ALARM_GENERAL_LEGACY_HEAT_PUMP_ALARM = "input_primary_unit_alarm_general_legacy_heat_pump_alarm"
ATTR_INPUT_PRIMARY_UNIT_ALARM_PRIMARY_UNIT_CAN_NOT_COMMUNICATE_WITH_EXPANSION = "input_primary_unit_alarm_primary_unit_can_not_communicate_with_expansion"
ATTR_HOLDING_OPERATIONAL_MODE = "holding_operational_mode"
ATTR_HOLDING_MAX_LIMITATION = "holding_max_limitation"
ATTR_HOLDING_MIN_LIMITATION = "holding_min_limitation"
ATTR_HOLDING_COMFORT_WHEEL_SETTING = "holding_comfort_wheel_setting"
ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_1 = "holding_set_point_heat_curve_y_1"
ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_2 = "holding_set_point_heat_curve_y_2"
ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_3 = "holding_set_point_heat_curve_y_3"
ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_4 = "holding_set_point_heat_curve_y_4"
ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_5 = "holding_set_point_heat_curve_y_5"
ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_6 = "holding_set_point_heat_curve_y_6"
ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_7 = "holding_set_point_heat_curve_y_7"
ATTR_HOLDING_HEATING_SEASON_STOP_TEMPERATURE = "holding_heating_season_stop_temperature"
ATTR_HOLDING_START_TEMPERATURE_TAP_WATER = "holding_start_temperature_tap_water"
ATTR_HOLDING_STOP_TEMPERATURE_TAP_WATER = "holding_stop_temperature_tap_water"
ATTR_HOLDING_MINIMUM_ALLOWED_GEAR_IN_HEATING = "holding_minimum_allowed_gear_in_heating"
ATTR_HOLDING_MAXIMUM_ALLOWED_GEAR_IN_HEATING = "holding_maximum_allowed_gear_in_heating"
ATTR_HOLDING_MAXIMUM_ALLOWED_GEAR_IN_TAP_WATER = "holding_maximum_allowed_gear_in_tap_water"
ATTR_HOLDING_MINIMUM_ALLOWED_GEAR_IN_TAP_WATER = "holding_minimum_allowed_gear_in_tap_water"
ATTR_HOLDING_COOLING_MIX_VALVE_SET_POINT = "holding_cooling_mix_valve_set_point"
ATTR_HOLDING_TWC_MIX_VALVE_SET_POINT = "holding_twc_mix_valve_set_point"
ATTR_HOLDING_WCS_RETURN_LINE_SET_POINT = "holding_wcs_return_line_set_point"
ATTR_HOLDING_TWC_MIX_VALVE_LOWEST_ALLOWED_OPENING_DEGREE = "holding_twc_mix_valve_lowest_allowed_opening_degree"
ATTR_HOLDING_TWC_MIX_VALVE_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_twc_mix_valve_highest_allowed_opening_degree"
ATTR_HOLDING_TWC_START_TEMPERATURE_IMMERSION_HEATER = "holding_twc_start_temperature_immersion_heater"
ATTR_HOLDING_TWC_START_DELAY_IMMERSION_HEATER = "holding_twc_start_delay_immersion_heater"
ATTR_HOLDING_TWC_STOP_TEMPERATURE_IMMERSION_HEATER = "holding_twc_stop_temperature_immersion_heater"
ATTR_HOLDING_WCS_MIX_VALVE_LOWEST_ALLOWED_OPENING_DEGREE = "holding_wcs_mix_valve_lowest_allowed_opening_degree"
ATTR_HOLDING_WCS_MIX_VALVE_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_wcs_mix_valve_highest_allowed_opening_degree"
ATTR_HOLDING_MIX_VALVE_2_LOWEST_ALLOWED_OPENING_DEGREE = "holding_mix_valve_2_lowest_allowed_opening_degree"
ATTR_HOLDING_MIX_VALVE_2_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_mix_valve_2_highest_allowed_opening_degree"
ATTR_HOLDING_MIX_VALVE_3_LOWEST_ALLOWED_OPENING_DEGREE = "holding_mix_valve_3_lowest_allowed_opening_degree"
ATTR_HOLDING_MIX_VALVE_3_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_mix_valve_3_highest_allowed_opening_degree"
ATTR_HOLDING_MIX_VALVE_4_LOWEST_ALLOWED_OPENING_DEGREE = "holding_mix_valve_4_lowest_allowed_opening_degree"
ATTR_HOLDING_MIX_VALVE_4_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_mix_valve_4_highest_allowed_opening_degree"
ATTR_HOLDING_MIX_VALVE_5_LOWEST_ALLOWED_OPENING_DEGREE = "holding_mix_valve_5_lowest_allowed_opening_degree"
ATTR_HOLDING_MIX_VALVE_5_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_mix_valve_5_highest_allowed_opening_degree"
ATTR_HOLDING_SURPLUS_HEAT_CHILLER_SET_POINT = "holding_surplus_heat_chiller_set_point"
ATTR_HOLDING_COOLING_SUPPLY_LINE_MIX_VALVE_LOWEST_ALLOWED_OPENING_DEGREE = "holding_cooling_supply_line_mix_valve_lowest_allowed_opening_degree"
ATTR_HOLDING_COOLING_SUPPLY_LINE_MIX_VALVE_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_cooling_supply_line_mix_valve_highest_allowed_opening_degree"
ATTR_HOLDING_SURPLUS_HEAT_OPENING_DEGREE_FOR_STARTING_FAN_1 = "holding_surplus_heat_opening_degree_for_starting_fan_1"
ATTR_HOLDING_SURPLUS_HEAT_OPENING_DEGREE_FOR_STARTING_FAN_2 = "holding_surplus_heat_opening_degree_for_starting_fan_2"
ATTR_HOLDING_SURPLUS_HEAT_OPENING_DEGREE_FOR_STOPPING_FAN_1 = "holding_surplus_heat_opening_degree_for_stopping_fan_1"
ATTR_HOLDING_SURPLUS_HEAT_OPENING_DEGREE_FOR_STOPPING_FAN_2 = "holding_surplus_heat_opening_degree_for_stopping_fan_2"
ATTR_HOLDING_SURPLUS_HEAT_LOWEST_ALLOWED_OPENING_DEGREE = "holding_surplus_heat_lowest_allowed_opening_degree"
ATTR_HOLDING_SURPLUS_HEAT_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_surplus_heat_highest_allowed_opening_degree"
ATTR_HOLDING_POOL_CHARGE_SET_POINT = "holding_pool_charge_set_point"
ATTR_HOLDING_POOL_MIX_VALVE_LOWEST_ALLOWED_OPENING_DEGREE = "holding_pool_mix_valve_lowest_allowed_opening_degree"
ATTR_HOLDING_POOL_MIX_VALVE_HIGHEST_ALLOWED_OPENING_DEGREE = "holding_pool_mix_valve_highest_allowed_opening_degree"
ATTR_HOLDING_GEAR_SHIFT_DELAY_HEATING = "holding_gear_shift_delay_heating"
ATTR_HOLDING_GEAR_SHIFT_DELAY_POOL = "holding_gear_shift_delay_pool"
ATTR_HOLDING_GEAR_SHIFT_DELAY_COOLING = "holding_gear_shift_delay_cooling"
ATTR_HOLDING_BRINE_IN_HIGH_ALARM_LIMIT = "holding_brine_in_high_alarm_limit"
ATTR_HOLDING_BRINE_IN_LOW_ALARM_LIMIT = "holding_brine_in_low_alarm_limit"
ATTR_HOLDING_BRINE_OUT_LOW_ALARM_LIMIT = "holding_brine_out_low_alarm_limit"
ATTR_HOLDING_BRINE_MAX_DELTA_LIMIT = "holding_brine_max_delta_limit"
ATTR_HOLDING_HOT_GAS_PUMP_START_TEMPERATURE_DISCHARGE_PIPE = "holding_hot_gas_pump_start_temperature_discharge_pipe"
ATTR_HOLDING_HOT_GAS_PUMP_LOWER_STOP_LIMIT_TEMPERATURE_DISCHARGE_PIPE = "holding_hot_gas_pump_lower_stop_limit_temperature_discharge_pipe"
ATTR_HOLDING_HOT_GAS_PUMP_UPPER_STOP_LIMIT_TEMPERATURE_DISCHARGE_PIPE = "holding_hot_gas_pump_upper_stop_limit_temperature_discharge_pipe"
ATTR_HOLDING_EXTERNAL_ADDITIONAL_HEATER_START = "holding_external_additional_heater_start"
ATTR_HOLDING_CONDENSER_PUMP_LOWEST_ALLOWED_SPEED = "holding_condenser_pump_lowest_allowed_speed"
ATTR_HOLDING_BRINE_PUMP_LOWEST_ALLOWED_SPEED = "holding_brine_pump_lowest_allowed_speed"
ATTR_HOLDING_EXTERNAL_ADDITIONAL_HEATER_STOP = "holding_external_additional_heater_stop"
ATTR_HOLDING_CONDENSER_PUMP_HIGHEST_ALLOWED_SPEED = "holding_condenser_pump_highest_allowed_speed"
ATTR_HOLDING_BRINE_PUMP_HIGHEST_ALLOWED_SPEED = "holding_brine_pump_highest_allowed_speed"
ATTR_HOLDING_CONDENSER_PUMP_STANDBY_SPEED = "holding_condenser_pump_standby_speed"
ATTR_HOLDING_BRINE_PUMP_STANDBY_SPEED = "holding_brine_pump_standby_speed"
ATTR_HOLDING_MINIMUM_ALLOWED_GEAR_IN_POOL = "holding_minimum_allowed_gear_in_pool"
ATTR_HOLDING_MAXIMUM_ALLOWED_GEAR_IN_POOL = "holding_maximum_allowed_gear_in_pool"
ATTR_HOLDING_MINIMUM_ALLOWED_GEAR_IN_COOLING = "holding_minimum_allowed_gear_in_cooling"
ATTR_HOLDING_MAXIMUM_ALLOWED_GEAR_IN_COOLING = "holding_maximum_allowed_gear_in_cooling"
ATTR_HOLDING_START_TEMP_FOR_COOLING = "holding_start_temp_for_cooling"
ATTR_HOLDING_STOP_TEMP_FOR_COOLING = "holding_stop_temp_for_cooling"
ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_1 = "holding_min_limitation_set_point_curve_radiator_mix_valve_1"
ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_1 = "holding_max_limitation_set_point_curve_radiator_mix_valve_1"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_1 = "holding_set_point_curve_y_coordinate_1_mix_valve_1"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_1 = "holding_set_point_curve_y_coordinate_2_mix_valve_1"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_1 = "holding_set_point_curve_y_coordinate_3_mix_valve_1"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_1 = "holding_set_point_curve_y_coordinate_4_mix_valve_1"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_1 = "holding_set_point_curve_y_coordinate_5_mix_valve_1"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_1 = "holding_set_point_curve_y_coordinate_6_mix_valve_1"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_1 = "holding_set_point_curve_y_coordinate_7_mix_valve_1"
ATTR_HOLDING_FIXED_SYSTEM_SUPPLY_SET_POINT = "holding_fixed_system_supply_set_point"
ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_2 = "holding_min_limitation_set_point_curve_radiator_mix_valve_2"
ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_2 = "holding_max_limitation_set_point_curve_radiator_mix_valve_2"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_2 = "holding_set_point_curve_y_coordinate_1_mix_valve_2"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_2 = "holding_set_point_curve_y_coordinate_2_mix_valve_2"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_2 = "holding_set_point_curve_y_coordinate_3_mix_valve_2"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_2 = "holding_set_point_curve_y_coordinate_4_mix_valve_2"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_2 = "holding_set_point_curve_y_coordinate_5_mix_valve_2"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_2 = "holding_set_point_curve_y_coordinate_6_mix_valve_2"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_2 = "holding_set_point_curve_y_coordinate_7_mix_valve_2"
ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_3 = "holding_min_limitation_set_point_curve_radiator_mix_valve_3"
ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_3 = "holding_max_limitation_set_point_curve_radiator_mix_valve_3"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_3 = "holding_set_point_curve_y_coordinate_1_mix_valve_3"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_3 = "holding_set_point_curve_y_coordinate_2_mix_valve_3"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_3 = "holding_set_point_curve_y_coordinate_3_mix_valve_3"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_3 = "holding_set_point_curve_y_coordinate_4_mix_valve_3"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_3 = "holding_set_point_curve_y_coordinate_5_mix_valve_3"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_3 = "holding_set_point_curve_y_coordinate_6_mix_valve_3"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_3 = "holding_set_point_curve_y_coordinate_7_mix_valve_3"
ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_4 = "holding_min_limitation_set_point_curve_radiator_mix_valve_4"
ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_4 = "holding_max_limitation_set_point_curve_radiator_mix_valve_4"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_4 = "holding_set_point_curve_y_coordinate_1_mix_valve_4"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_4 = "holding_set_point_curve_y_coordinate_2_mix_valve_4"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_4 = "holding_set_point_curve_y_coordinate_3_mix_valve_4"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_4 = "holding_set_point_curve_y_coordinate_4_mix_valve_4"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_4 = "holding_set_point_curve_y_coordinate_5_mix_valve_4"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_4 = "holding_set_point_curve_y_coordinate_6_mix_valve_4"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_4 = "holding_set_point_curve_y_coordinate_7_mix_valve_4"
ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_5 = "holding_min_limitation_set_point_curve_radiator_mix_valve_5"
ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_5 = "holding_max_limitation_set_point_curve_radiator_mix_valve_5"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_5 = "holding_set_point_curve_y_coordinate_1_mix_valve_5"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_5 = "holding_set_point_curve_y_coordinate_2_mix_valve_5"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_5 = "holding_set_point_curve_y_coordinate_3_mix_valve_5"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_5 = "holding_set_point_curve_y_coordinate_4_mix_valve_5"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_5 = "holding_set_point_curve_y_coordinate_5_mix_valve_5"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_5 = "holding_set_point_curve_y_coordinate_6_mix_valve_5"
ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_5 = "holding_set_point_curve_y_coordinate_7_mix_valve_5"
ATTR_HOLDING_SET_POINT_RETURN_TEMP_FROM_POOL_TO_HEAT_EXCHANGER = "holding_set_point_return_temp_from_pool_to_heat_exchanger"
ATTR_HOLDING_SET_POINT_POOL_HYSTERESIS = "holding_set_point_pool_hysteresis"
ATTR_HOLDING_SET_POINT_FOR_SUPPLY_LINE_TEMP_PASSIVE_COOLING_WITH_MIXING_VALVE_1 = "holding_set_point_for_supply_line_temp_passive_cooling_with_mixing_valve_1"
ATTR_HOLDING_SET_POINT_MINIMUM_OUTDOOR_TEMP_WHEN_COOLING_IS_PERMITTED = "holding_set_point_minimum_outdoor_temp_when_cooling_is_permitted"
ATTR_HOLDING_EXTERNAL_HEATER_OUTDOOR_TEMP_LIMIT = "holding_external_heater_outdoor_temp_limit"
ATTR_HOLDING_SELECTED_MODE_FOR_MIXING_VALVE_2 = "holding_selected_mode_for_mixing_valve_2"
ATTR_HOLDING_DESIRED_COOLING_TEMPERATURE_SETPOINT_MIXING_VALVE_2 = "holding_desired_cooling_temperature_setpoint_mixing_valve_2"
ATTR_HOLDING_SEASONAL_COOLING_TEMPERATURE_OUTDOOR_MIXING_VALVE_2 = "holding_seasonal_cooling_temperature_outdoor_mixing_valve_2"
ATTR_HOLDING_SEASONAL_HEATING_TEMPERATURE_OUTDOOR_MIXING_VALVE_2 = "holding_seasonal_heating_temperature_outdoor_mixing_valve_2"
ATTR_HOLDING_SELECTED_MODE_FOR_MIXING_VALVE_3 = "holding_selected_mode_for_mixing_valve_3"
ATTR_HOLDING_DESIRED_COOLING_TEMPERATURE_SETPOINT_MIXING_VALVE_3 = "holding_desired_cooling_temperature_setpoint_mixing_valve_3"
ATTR_HOLDING_SEASONAL_COOLING_TEMPERATURE_OUTDOOR_MIXING_VALVE_3 = "holding_seasonal_cooling_temperature_outdoor_mixing_valve_3"
ATTR_HOLDING_SEASONAL_HEATING_TEMPERATURE_OUTDOOR_MIXING_VALVE_3 = "holding_seasonal_heating_temperature_outdoor_mixing_valve_3"
ATTR_HOLDING_SELECTED_MODE_FOR_MIXING_VALVE_4 = "holding_selected_mode_for_mixing_valve_4"
ATTR_HOLDING_DESIRED_COOLING_TEMPERATURE_SETPOINT_MIXING_VALVE_4 = "holding_desired_cooling_temperature_setpoint_mixing_valve_4"
ATTR_HOLDING_SEASONAL_COOLING_TEMPERATURE_OUTDOOR_MIXING_VALVE_4 = "holding_seasonal_cooling_temperature_outdoor_mixing_valve_4"
ATTR_HOLDING_SEASONAL_HEATING_TEMPERATURE_OUTDOOR_TEMP_MIXING_VALVE_4 = "holding_seasonal_heating_temperature_outdoor_temp_mixing_valve_4"
ATTR_HOLDING_SELECTED_MODE_FOR_MIXING_VALVE_5 = "holding_selected_mode_for_mixing_valve_5"
ATTR_HOLDING_DESIRED_COOLING_TEMPERATURE_SETPOINT_MIXING_VALVE_5 = "holding_desired_cooling_temperature_setpoint_mixing_valve_5"
ATTR_HOLDING_SEASONAL_COOLING_TEMPERATURE_OUTDOOR_MIXING_VALVE_5 = "holding_seasonal_cooling_temperature_outdoor_mixing_valve_5"
ATTR_HOLDING_SEASONAL_HEATING_TEMPERATURE_OUTDOOR_MIXING_VALVE_5 = "holding_seasonal_heating_temperature_outdoor_mixing_valve_5"

REGISTERS = {
    ATTR_COIL_RESET_ALL_ALARMS:
        { KEY_ADDRESS: 3, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_INTERNAL_ADDITIONAL_HEATER:
        { KEY_ADDRESS: 4, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_EXTERNAL_ADDITIONAL_HEATER:
        { KEY_ADDRESS: 5, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_HGW:
        { KEY_ADDRESS: 6, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_FLOW_SWITCH_PRESSURE_SWITCH:
        { KEY_ADDRESS: 7, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_TAP_WATER:
        { KEY_ADDRESS: 8, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_HEAT:
        { KEY_ADDRESS: 9, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_ACTIVE_COOLING:
        { KEY_ADDRESS: 10, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_MIX_VALVE_1:
        { KEY_ADDRESS: 11, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_TWC:
        { KEY_ADDRESS: 12, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_WCS:
        { KEY_ADDRESS: 13, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_HOT_GAS_PUMP:
        { KEY_ADDRESS: 14, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_MIX_VALVE_2:
        { KEY_ADDRESS: 16, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_MIX_VALVE_3:
        { KEY_ADDRESS: 17, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_MIX_VALVE_4:
        { KEY_ADDRESS: 18, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_MIX_VALVE_5:
        { KEY_ADDRESS: 19, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_BRINE_OUT_MONITORING:
        { KEY_ADDRESS: 20, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_BRINE_PUMP_CONTINUOUS_OPERATION:
        { KEY_ADDRESS: 21, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_SYSTEM_CIRCULATION_PUMP:
        { KEY_ADDRESS: 22, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_DEW_POINT_CALCULATION:
        { KEY_ADDRESS: 23, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_ANTI_LEGIONELLA:
        { KEY_ADDRESS: 24, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_ADDITIONAL_HEATER_ONLY:
        { KEY_ADDRESS: 25, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_CURRENT_LIMITATION:
        { KEY_ADDRESS: 26, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_POOL:
        { KEY_ADDRESS: 28, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_SURPLUS_HEAT_CHILLER:
        { KEY_ADDRESS: 29, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_SURPLUS_HEAT_BOREHOLE:
        { KEY_ADDRESS: 30, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_EXTERNAL_ADDITIONAL_HEATER_FOR_POOL:
        { KEY_ADDRESS: 31, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_INTERNAL_ADDITIONAL_HEATER_FOR_POOL:
        { KEY_ADDRESS: 32, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_PASSIVE_COOLING:
        { KEY_ADDRESS: 33, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_VARIABLE_SPEED_MODE_FOR_CONDENSER_PUMP:
        { KEY_ADDRESS: 34, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_VARIABLE_SPEED_MODE_FOR_BRINE_PUMP:
        { KEY_ADDRESS: 35, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_COOLING_MODE_FOR_MIXING_VALVE_1:
        { KEY_ADDRESS: 36, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_1:
        { KEY_ADDRESS: 37, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_1:
        { KEY_ADDRESS: 38, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_EXTERNAL_HEATER:
        { KEY_ADDRESS: 39, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_BRINE_IN_MONITORING:
        { KEY_ADDRESS: 40, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_COIL_ENABLE_FIXED_SYSTEM_SUPPLY_SET_POINT:
        { KEY_ADDRESS: 41, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_EVAPORATOR_FREEZE_PROTECTION:
        { KEY_ADDRESS: 42, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_2:
        { KEY_ADDRESS: 43, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_DEW_POINT_CALCULATION_ON_MIXING_VALVE_2:
        { KEY_ADDRESS: 44, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_HEATING_WITH_MIXING_VALVE_2:
        { KEY_ADDRESS: 45, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_3:
        { KEY_ADDRESS: 46, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_DEW_POINT_CALCULATION_ON_MIXING_VALVE_3:
        { KEY_ADDRESS: 47, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_HEATING_WITH_MIXING_VALVE_3:
        { KEY_ADDRESS: 48, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_4:
        { KEY_ADDRESS: 49, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_DEW_POINT_CALCULATION_ON_MIXING_VALVE_4:
        { KEY_ADDRESS: 50, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_HEATING_WITH_MIXING_VALVE_4:
        { KEY_ADDRESS: 51, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_COOLING_WITH_MIXING_VALVE_5:
        { KEY_ADDRESS: 52, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_DEW_POINT_CALCULATION_ON_MIXING_VALVE_5:
        { KEY_ADDRESS: 53, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_OUTDOOR_TEMP_DEPENDENT_FOR_HEATING_WITH_MIXING_VALVE_5:
        { KEY_ADDRESS: 54, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_2:
        { KEY_ADDRESS: 55, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_3:
        { KEY_ADDRESS: 56, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_4:
        { KEY_ADDRESS: 57, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_COIL_ENABLE_INTERNAL_BRINE_PUMP_TO_START_WHEN_COOLING_IS_ACTIVE_FOR_MIXING_VALVE_5:
        { KEY_ADDRESS: 58, KEY_REG_TYPE: REG_COIL, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_ALARM_ACTIVE_CLASS_A:
        { KEY_ADDRESS: 0, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_ALARM_ACTIVE_CLASS_B:
        { KEY_ADDRESS: 1, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_ALARM_ACTIVE_CLASS_C:
        { KEY_ADDRESS: 2, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_ALARM_ACTIVE_CLASS_D:
        { KEY_ADDRESS: 3, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_ALARM_ACTIVE_CLASS_E:
        { KEY_ADDRESS: 4, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_HIGH_PRESSURE_SWITCH_ALARM:
        { KEY_ADDRESS: 9, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_LOW_PRESSURE_LEVEL_ALARM:
        { KEY_ADDRESS: 10, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_HIGH_DISCHARGE_PIPE_TEMPERATURE_ALARM:
        { KEY_ADDRESS: 11, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_OPERATING_PRESSURE_LIMIT_INDICATION:
        { KEY_ADDRESS: 12, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_DISCHARGE_PIPE_SENSOR_ALARM:
        { KEY_ADDRESS: 13, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_LIQUID_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 14, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_SUCTION_GAS_SENSOR_ALARM:
        { KEY_ADDRESS: 15, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_FLOW_PRESSURE_SWITCH_ALARM:
        { KEY_ADDRESS: 16, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_POWER_INPUT_PHASE_DETECTION_ALARM:
        { KEY_ADDRESS: 22, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_INVERTER_UNIT_ALARM:
        { KEY_ADDRESS: 23, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_SYSTEM_SUPPLY_LOW_TEMPERATURE_ALARM:
        { KEY_ADDRESS: 24, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_COMPRESSOR_LOW_SPEED_ALARM:
        { KEY_ADDRESS: 25, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_LOW_SUPER_HEAT_ALARM:
        { KEY_ADDRESS: 26, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_PRESSURE_RATIO_OUT_OF_RANGE_ALARM:
        { KEY_ADDRESS: 27, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_COMPRESSOR_PRESSURE_OUTSIDE_ENVELOPE_ALARM:
        { KEY_ADDRESS: 28, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_BRINE_TEMPERATURE_OUT_OF_RANGE_ALARM:
        { KEY_ADDRESS: 29, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_BRINE_IN_SENSOR_ALARM:
        { KEY_ADDRESS: 30, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_BRINE_OUT_SENSOR_ALARM:
        { KEY_ADDRESS: 31, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_CONDENSER_IN_SENSOR_ALARM:
        { KEY_ADDRESS: 32, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_CONDENSER_OUT_SENSOR_ALARM:
        { KEY_ADDRESS: 33, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_OUTDOOR_SENSOR_ALARM:
        { KEY_ADDRESS: 34, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_SYSTEM_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 35, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_1_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 36, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_2_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 37, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_3_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 38, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_4_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 39, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_5_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 40, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_WCS_RETURN_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 44, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_TWC_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 45, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_COOLING_TANK_SENSOR_ALARM:
        { KEY_ADDRESS: 46, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_COOLING_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 47, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_COOLING_CIRCUIT_RETURN_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 48, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_BRINE_DELTA_OUT_OF_RANGE_ALARM:
        { KEY_ADDRESS: 49, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_TAP_WATER_MID_SENSOR_ALARM:
        { KEY_ADDRESS: 50, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_TWC_CIRCULATION_RETURN_SENSOR_ALARM:
        { KEY_ADDRESS: 51, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_HGW_SENSOR_ALARM:
        { KEY_ADDRESS: 52, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_DINPUT_INTERNAL_ADDITIONAL_HEATER_ALARM:
        { KEY_ADDRESS: 53, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_DINPUT_BRINE_IN_HIGH_TEMPERATURE_ALARM:
        { KEY_ADDRESS: 55, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_BRINE_IN_LOW_TEMPERATURE_ALARM:
        { KEY_ADDRESS: 56, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_BRINE_OUT_LOW_TEMPERATURE_ALARM:
        { KEY_ADDRESS: 57, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_TWC_CIRCULATION_RETURN_LOW_TEMPERATURE_ALARM:
        { KEY_ADDRESS: 58, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_TWC_SUPPLY_LOW_TEMPERATURE_ALARM:
        { KEY_ADDRESS: 59, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_1_SUPPLY_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 60, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_2_SUPPLY_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 61, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_3_SUPPLY_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 62, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_4_SUPPLY_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 63, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_5_SUPPLY_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 64, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_WCS_RETURN_LINE_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 65, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_SUM_ALARM:
        { KEY_ADDRESS: 66, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_COOLING_CIRCUIT_SUPPLY_LINE_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 67, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_COOLING_TANK_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 68, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_SURPLUS_HEAT_TEMPERATURE_DEVIATION_ALARM:
        { KEY_ADDRESS: 69, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_HUMIDITY_ROOM_SENSOR_ALARM:
        { KEY_ADDRESS: 70, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_SURPLUS_HEAT_SUPPLY_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 71, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_SURPLUS_HEAT_RETURN_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 72, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_COOLING_TANK_RETURN_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 73, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_TEMPERATURE_ROOM_SENSOR_ALARM:
        { KEY_ADDRESS: 74, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_INVERTER_UNIT_COMMUNICATION_ALARM:
        { KEY_ADDRESS: 75, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_POOL_RETURN_LINE_SENSOR_ALARM:
        { KEY_ADDRESS: 76, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_EXTERNAL_STOP_FOR_POOL:
        { KEY_ADDRESS: 77, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_EXTERNAL_START_BRINE_PUMP:
        { KEY_ADDRESS: 78, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_EXTERNAL_RELAY_FOR_BRINE_GROUND_WATER_PUMP:
        { KEY_ADDRESS: 79, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_TAP_WATER_END_TANK_SENSOR_ALARM:
        { KEY_ADDRESS: 81, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MAXIMUM_TIME_FOR_ANTI_LEGIONELLA_EXCEEDED_ALARM:
        { KEY_ADDRESS: 82, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_DINPUT_GENESIS_SECONDARY_UNIT_ALARM:
        { KEY_ADDRESS: 83, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_PRIMARY_UNIT_CONFLICT_ALARM:
        { KEY_ADDRESS: 84, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_PRIMARY_UNIT_NO_SECONDARY_ALARM:
        { KEY_ADDRESS: 85, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_OIL_BOOST_IN_PROGRESS:
        { KEY_ADDRESS: 86, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_COMPRESSOR_CONTROL_SIGNAL:
        { KEY_ADDRESS: 199, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_SMART_GRID_1:
        { KEY_ADDRESS: 201, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_EXTERNAL_ALARM_INPUT:
        { KEY_ADDRESS: 202, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_SMART_GRID_2:
        { KEY_ADDRESS: 204, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_EXTERNAL_ADDITIONAL_HEATER_CONTROL_SIGNAL:
        { KEY_ADDRESS: 206, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_MIX_VALVE_1_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 209, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_CONDENSER_PUMP_ON_OFF_CONTROL:
        { KEY_ADDRESS: 210, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_SYSTEM_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 211, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_HOT_GAS_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 213, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_BRINE_PUMP_ON_OFF_CONTROL:
        { KEY_ADDRESS: 218, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_EXTERNAL_HEATER_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 219, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_HEATING_SEASON_ACTIVE:
        { KEY_ADDRESS: 220, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_EXTERNAL_ADDITIONAL_HEATER_ACTIVE:
        { KEY_ADDRESS: 221, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_INTERNAL_ADDITIONAL_HEATER_ACTIVE:
        { KEY_ADDRESS: 222, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_DINPUT_HGW_REGULATION_CONTROL_SIGNAL:
        { KEY_ADDRESS: 223, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_DINPUT_HEAT_PUMP_STOPPING:
        { KEY_ADDRESS: 224, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_HEAT_PUMP_OK_TO_START:
        { KEY_ADDRESS: 225, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_TWC_SUPPLY_LINE_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 230, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_WCS_REGULATION_CONTROL_SIGNAL:
        { KEY_ADDRESS: 232, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_WCS_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 233, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_TWC_END_TANK_HEATER_CONTROL_SIGNAL:
        { KEY_ADDRESS: 234, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_POOL_DIRECTIONAL_VALVE_POSITION:
        { KEY_ADDRESS: 235, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_COOLING_CIRCUIT_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 236, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_POOL_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 237, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_SURPLUS_HEAT_DIRECTIONAL_VALVE_POSITION:
        { KEY_ADDRESS: 238, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_SURPLUS_HEAT_CIRCULATION_PUMP_CONTROL_SIGNAL:
        { KEY_ADDRESS: 239, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_COOLING_CIRCUIT_REGULATION_CONTROL_SIGNAL:
        { KEY_ADDRESS: 240, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_SURPLUS_HEAT_REGULATION_CONTROL_SIGNAL:
        { KEY_ADDRESS: 241, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_ACTIVE_COOLING_DIRECTIONAL_VALVE_POSITION:
        { KEY_ADDRESS: 242, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_PASSIVE_ACTIVE_COOLING_DIRECTIONAL_VALVE_POSITION:
        { KEY_ADDRESS: 243, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_DINPUT_POOL_REGULATION_CONTROL_SIGNAL:
        { KEY_ADDRESS: 244, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_INDICATION_WHEN_MIXING_VALVE_1_IS_PRODUCING_PASSIVE_COOLING:
        { KEY_ADDRESS: 245, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_DINPUT_COMPRESSOR_IS_UNABLE_TO_SPEED_UP:
        { KEY_ADDRESS: 246, KEY_REG_TYPE: REG_DISCRETE_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_BIT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_FIRST_PRIORITISED_DEMAND:
        { KEY_ADDRESS: 1, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_STATUS, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_COMPRESSOR_AVAILABLE_GEARS:
        { KEY_ADDRESS: 4, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_COMPRESSOR_SPEED_RPM:
        { KEY_ADDRESS: 5, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_EXTERNAL_ADDITIONAL_HEATER_CURRENT_DEMAND:
        { KEY_ADDRESS: 6, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DISCHARGE_PIPE_TEMPERATURE:
        { KEY_ADDRESS: 7, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_CONDENSER_IN_TEMPERATURE:
        { KEY_ADDRESS: 8, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_CONDENSER_OUT_TEMPERATURE:
        { KEY_ADDRESS: 9, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_BRINE_IN_TEMPERATURE:
        { KEY_ADDRESS: 10, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_BRINE_OUT_TEMPERATURE:
        { KEY_ADDRESS: 11, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SYSTEM_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 12, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_OUTDOOR_TEMPERATURE:
        { KEY_ADDRESS: 13, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_TAP_WATER_TOP_TEMPERATURE:
        { KEY_ADDRESS: 15, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_TAP_WATER_LOWER_TEMPERATURE:
        { KEY_ADDRESS: 16, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_TAP_WATER_WEIGHTED_TEMPERATURE:
        { KEY_ADDRESS: 17, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SYSTEM_SUPPLY_LINE_CALCULATED_SET_POINT:
        { KEY_ADDRESS: 18, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SELECTED_HEAT_CURVE:
        { KEY_ADDRESS: 19, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HEAT_CURVE_X_COORDINATE_1:
        { KEY_ADDRESS: 20, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HEAT_CURVE_X_COORDINATE_2:
        { KEY_ADDRESS: 21, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HEAT_CURVE_X_COORDINATE_3:
        { KEY_ADDRESS: 22, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HEAT_CURVE_X_COORDINATE_4:
        { KEY_ADDRESS: 23, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HEAT_CURVE_X_COORDINATE_5:
        { KEY_ADDRESS: 24, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HEAT_CURVE_X_COORDINATE_6:
        { KEY_ADDRESS: 25, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HEAT_CURVE_X_COORDINATE_7:
        { KEY_ADDRESS: 26, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_COOLING_SEASON_INTEGRAL_VALUE:
        { KEY_ADDRESS: 36, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_CONDENSER_CIRCULATION_PUMP_SPEED:
        { KEY_ADDRESS: 39, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_1_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 40, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_BUFFER_TANK_TEMPERATURE:
        { KEY_ADDRESS: 41, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_1_POSITION:
        { KEY_ADDRESS: 43, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_BRINE_CIRCULATION_PUMP_SPEED:
        { KEY_ADDRESS: 44, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HGW_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 45, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_HOT_WATER_DIRECTIONAL_VALVE_POSITION:
        { KEY_ADDRESS: 47, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_COMPRESSOR_OPERATING_HOURS:
        { KEY_ADDRESS: 48, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_LONG, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_TAP_WATER_OPERATING_HOURS:
        { KEY_ADDRESS: 50, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_LONG, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_EXTERNAL_ADDITIONAL_HEATER_OPERATING_HOURS:
        { KEY_ADDRESS: 52, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_LONG, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_COMPRESSOR_SPEED_PERCENT:
        { KEY_ADDRESS: 54, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SECOND_PRIORITISED_DEMAND:
        { KEY_ADDRESS: 55, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_STATUS, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_THIRD_PRIORITISED_DEMAND:
        { KEY_ADDRESS: 56, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_STATUS, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SOFTWARE_VERSION_MAJOR:
        { KEY_ADDRESS: 57, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SOFTWARE_VERSION_MINOR:
        { KEY_ADDRESS: 58, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SOFTWARE_VERSION_MICRO:
        { KEY_ADDRESS: 59, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_COMPRESSOR_TEMPORARILY_BLOCKED:
        { KEY_ADDRESS: 60, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_COMPRESSOR_CURRENT_GEAR:
        { KEY_ADDRESS: 61, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_QUEUED_DEMAND_FIRST_PRIORITY:
        { KEY_ADDRESS: 62, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_STATUS, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_QUEUED_DEMAND_SECOND_PRIORITY:
        { KEY_ADDRESS: 63, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_STATUS, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_QUEUED_DEMAND_THIRD_PRIORITY:
        { KEY_ADDRESS: 64, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_STATUS, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_QUEUED_DEMAND_FOURTH_PRIORITY:
        { KEY_ADDRESS: 65, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_STATUS, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_QUEUED_DEMAND_FIFTH_PRIORITY:
        { KEY_ADDRESS: 66, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_STATUS, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_INTERNAL_ADDITIONAL_HEATER_CURRENT_STEP:
        { KEY_ADDRESS: 67, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_BUFFER_TANK_CHARGE_SET_POINT:
        { KEY_ADDRESS: 68, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L1_CURRENT:
        { KEY_ADDRESS: 69, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L2_CURRENT:
        { KEY_ADDRESS: 70, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L3_CURRENT:
        { KEY_ADDRESS: 71, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L1_0_VOLTAGE:
        { KEY_ADDRESS: 72, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L2_0_VOLTAGE:
        { KEY_ADDRESS: 73, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L3_0_VOLTAGE:
        { KEY_ADDRESS: 74, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L1_L2_VOLTAGE:
        { KEY_ADDRESS: 75, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 10, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L2_L3_VOLTAGE:
        { KEY_ADDRESS: 76, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 10, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L3_L1_VOLTAGE:
        { KEY_ADDRESS: 77, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 10, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L1_POWER:
        { KEY_ADDRESS: 78, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L2_POWER:
        { KEY_ADDRESS: 79, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_L3_POWER:
        { KEY_ADDRESS: 80, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_METER_VALUE:
        { KEY_ADDRESS: 81, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_COMFORT_MODE:
        { KEY_ADDRESS: 82, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_ELECTRIC_METER_KWH_TOTAL:
        { KEY_ADDRESS: 83, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_LONG, MODEL_MEGA: False, MODEL_INVERTER: True },
    ATTR_INPUT_WCS_VALVE_POSITION:
        { KEY_ADDRESS: 85, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_TWC_VALVE_POSITION:
        { KEY_ADDRESS: 86, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_2_POSITION:
        { KEY_ADDRESS: 87, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_3_POSITION:
        { KEY_ADDRESS: 88, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_4_POSITION:
        { KEY_ADDRESS: 89, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_5_POSITION:
        { KEY_ADDRESS: 90, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DEW_POINT_ROOM:
        { KEY_ADDRESS: 91, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_COOLING_SUPPLY_LINE_MIX_VALVE_POSITION:
        { KEY_ADDRESS: 92, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_SURPLUS_HEAT_FAN_SPEED:
        { KEY_ADDRESS: 93, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_POOL_SUPPLY_LINE_MIX_VALVE_POSITION:
        { KEY_ADDRESS: 94, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_TWC_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 95, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_TWC_RETURN_TEMPERATURE:
        { KEY_ADDRESS: 96, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_WCS_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 97, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_TWC_END_TANK_TEMPERATURE:
        { KEY_ADDRESS: 98, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_2_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 99, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_3_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 100, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_4_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 101, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_COOLING_CIRCUIT_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 103, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_COOLING_TANK_TEMPERATURE:
        { KEY_ADDRESS: 104, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_COOLING_TANK_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 105, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_COOLING_CIRCUIT_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 106, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_MIX_VALVE_5_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 107, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_2_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 109, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_3_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 111, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_4_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 113, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_5_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 115, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SURPLUS_HEAT_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 117, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_SURPLUS_HEAT_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 118, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_POOL_SUPPLY_LINE_TEMPERATURE:
        { KEY_ADDRESS: 119, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_POOL_RETURN_LINE_TEMPERATURE:
        { KEY_ADDRESS: 120, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_ROOM_TEMPERATURE_SENSOR:
        { KEY_ADDRESS: 121, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 10, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_BUBBLE_POINT:
        { KEY_ADDRESS: 122, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DEW_POINT:
        { KEY_ADDRESS: 124, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SUPERHEAT_TEMPERATURE:
        { KEY_ADDRESS: 125, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SUB_COOLING_TEMPERATURE:
        { KEY_ADDRESS: 126, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_LOW_PRESSURE_SIDE:
        { KEY_ADDRESS: 127, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HIGH_PRESSURE_SIDE:
        { KEY_ADDRESS: 128, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_LIQUID_LINE_TEMPERATURE:
        { KEY_ADDRESS: 129, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_SUCTION_GAS_TEMPERATURE:
        { KEY_ADDRESS: 130, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_HEATING_SEASON_INTEGRAL_VALUE:
        { KEY_ADDRESS: 131, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_P_VALUE_FOR_GEAR_SHIFTING_AND_DEMAND_CALCULATION:
        { KEY_ADDRESS: 132, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_I_VALUE_FOR_GEAR_SHIFTING_AND_DEMAND_CALCULATION:
        { KEY_ADDRESS: 133, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_D_VALUE_FOR_GEAR_SHIFTING_AND_DEMAND_CALCULATION:
        { KEY_ADDRESS: 134, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_I_VALUE_FOR_COMPRESSOR_ON_OFF_BUFFER_TANK:
        { KEY_ADDRESS: 135, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_P_VALUE_FOR_COMPRESSOR_ON_OFF_BUFFER_TANK:
        { KEY_ADDRESS: 136, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MIX_VALVE_COOLING_OPENING_DEGREE:
        { KEY_ADDRESS: 137, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_GEAR_FOR_TAP_WATER:
        { KEY_ADDRESS: 139, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_GEAR_FOR_HEATING:
        { KEY_ADDRESS: 140, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_GEAR_FOR_COOLING:
        { KEY_ADDRESS: 141, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_GEAR_FOR_POOL:
        { KEY_ADDRESS: 142, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_NUMBER_OF_AVAILABLE_SECONDARIES_GENESIS:
        { KEY_ADDRESS: 143, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_NUMBER_OF_AVAILABLE_SECONDARIES_LEGACY:
        { KEY_ADDRESS: 144, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_TOTAL_DISTRIBUTED_GEARS_TO_ALL_UNITS:
        { KEY_ADDRESS: 145, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_MAXIMUM_GEAR_OUT_OF_ALL_THE_CURRENTLY_REQUESTED_GEARS:
        { KEY_ADDRESS: 146, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_1:
        { KEY_ADDRESS: 147, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_2:
        { KEY_ADDRESS: 148, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_3:
        { KEY_ADDRESS: 149, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_4:
        { KEY_ADDRESS: 150, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DESIRED_TEMPERATURE_DISTRIBUTION_CIRCUIT_MIX_VALVE_5:
        { KEY_ADDRESS: 151, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_INPUT_DISCONNECT_HOT_GAS_END_TANK:
        { KEY_ADDRESS: 152, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_LEGACY_HEAT_PUMP_COMPRESSOR_RUNNING:
        { KEY_ADDRESS: 153, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_LEGACY_HEAT_PUMP_REPORTING_ALARM:
        { KEY_ADDRESS: 154, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_LEGACY_HEAT_PUMP_START_SIGNAL:
        { KEY_ADDRESS: 155, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_LEGACY_HEAT_PUMP_TAP_WATER_SIGNAL:
        { KEY_ADDRESS: 156, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_PRIMARY_UNIT_ALARM_COMBINED_OUTPUT_OF_ALL_CLASS_D_ALARMS:
        { KEY_ADDRESS: 160, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_PRIMARY_UNIT_ALARM_PRIMARY_UNIT_HAS_LOST_COMMUNICATION:
        { KEY_ADDRESS: 161, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_PRIMARY_UNIT_ALARM_CLASS_A_ALARM_DETECTED_ON_THE_GENESIS_SECONDARY:
        { KEY_ADDRESS: 162, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_PRIMARY_UNIT_ALARM_CLASS_B_ALARM_DETECTED_ON_THE_GENESIS_SECONDARY:
        { KEY_ADDRESS: 163, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_PRIMARY_UNIT_ALARM_COMBINED_OUTPUT_OF_ALL_CLASS_E_ALARMS:
        { KEY_ADDRESS: 170, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_PRIMARY_UNIT_ALARM_GENERAL_LEGACY_HEAT_PUMP_ALARM:
        { KEY_ADDRESS: 171, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_INPUT_PRIMARY_UNIT_ALARM_PRIMARY_UNIT_CAN_NOT_COMMUNICATE_WITH_EXPANSION:
        { KEY_ADDRESS: 173, KEY_REG_TYPE: REG_INPUT, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_OPERATIONAL_MODE:
        { KEY_ADDRESS: 0, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAX_LIMITATION:
        { KEY_ADDRESS: 3, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIN_LIMITATION:
        { KEY_ADDRESS: 4, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_COMFORT_WHEEL_SETTING:
        { KEY_ADDRESS: 5, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_1:
        { KEY_ADDRESS: 6, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_2:
        { KEY_ADDRESS: 7, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_3:
        { KEY_ADDRESS: 8, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_4:
        { KEY_ADDRESS: 9, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_5:
        { KEY_ADDRESS: 10, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_6:
        { KEY_ADDRESS: 11, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_HEAT_CURVE_Y_7:
        { KEY_ADDRESS: 12, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_HEATING_SEASON_STOP_TEMPERATURE:
        { KEY_ADDRESS: 16, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_START_TEMPERATURE_TAP_WATER:
        { KEY_ADDRESS: 22, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_STOP_TEMPERATURE_TAP_WATER:
        { KEY_ADDRESS: 23, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MINIMUM_ALLOWED_GEAR_IN_HEATING:
        { KEY_ADDRESS: 26, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAXIMUM_ALLOWED_GEAR_IN_HEATING:
        { KEY_ADDRESS: 27, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAXIMUM_ALLOWED_GEAR_IN_TAP_WATER:
        { KEY_ADDRESS: 28, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MINIMUM_ALLOWED_GEAR_IN_TAP_WATER:
        { KEY_ADDRESS: 29, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_COOLING_MIX_VALVE_SET_POINT:
        { KEY_ADDRESS: 30, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_TWC_MIX_VALVE_SET_POINT:
        { KEY_ADDRESS: 31, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_WCS_RETURN_LINE_SET_POINT:
        { KEY_ADDRESS: 32, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_TWC_MIX_VALVE_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 33, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_TWC_MIX_VALVE_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 34, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_TWC_START_TEMPERATURE_IMMERSION_HEATER:
        { KEY_ADDRESS: 35, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_TWC_START_DELAY_IMMERSION_HEATER:
        { KEY_ADDRESS: 36, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_TWC_STOP_TEMPERATURE_IMMERSION_HEATER:
        { KEY_ADDRESS: 37, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_WCS_MIX_VALVE_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 38, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_WCS_MIX_VALVE_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 39, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_MIX_VALVE_2_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 40, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIX_VALVE_2_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 41, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIX_VALVE_3_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 42, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIX_VALVE_3_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 43, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIX_VALVE_4_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 44, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIX_VALVE_4_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 45, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIX_VALVE_5_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 46, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIX_VALVE_5_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 47, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SURPLUS_HEAT_CHILLER_SET_POINT:
        { KEY_ADDRESS: 48, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_COOLING_SUPPLY_LINE_MIX_VALVE_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 49, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_COOLING_SUPPLY_LINE_MIX_VALVE_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 50, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SURPLUS_HEAT_OPENING_DEGREE_FOR_STARTING_FAN_1:
        { KEY_ADDRESS: 51, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SURPLUS_HEAT_OPENING_DEGREE_FOR_STARTING_FAN_2:
        { KEY_ADDRESS: 52, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SURPLUS_HEAT_OPENING_DEGREE_FOR_STOPPING_FAN_1:
        { KEY_ADDRESS: 53, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SURPLUS_HEAT_OPENING_DEGREE_FOR_STOPPING_FAN_2:
        { KEY_ADDRESS: 54, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SURPLUS_HEAT_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 55, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SURPLUS_HEAT_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 56, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_POOL_CHARGE_SET_POINT:
        { KEY_ADDRESS: 58, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_POOL_MIX_VALVE_LOWEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 59, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_POOL_MIX_VALVE_HIGHEST_ALLOWED_OPENING_DEGREE:
        { KEY_ADDRESS: 60, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_GEAR_SHIFT_DELAY_HEATING:
        { KEY_ADDRESS: 61, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_GEAR_SHIFT_DELAY_POOL:
        { KEY_ADDRESS: 62, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_GEAR_SHIFT_DELAY_COOLING:
        { KEY_ADDRESS: 63, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_BRINE_IN_HIGH_ALARM_LIMIT:
        { KEY_ADDRESS: 67, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_BRINE_IN_LOW_ALARM_LIMIT:
        { KEY_ADDRESS: 68, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_BRINE_OUT_LOW_ALARM_LIMIT:
        { KEY_ADDRESS: 69, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_BRINE_MAX_DELTA_LIMIT:
        { KEY_ADDRESS: 70, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_HOT_GAS_PUMP_START_TEMPERATURE_DISCHARGE_PIPE:
        { KEY_ADDRESS: 71, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_HOT_GAS_PUMP_LOWER_STOP_LIMIT_TEMPERATURE_DISCHARGE_PIPE:
        { KEY_ADDRESS: 72, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_HOT_GAS_PUMP_UPPER_STOP_LIMIT_TEMPERATURE_DISCHARGE_PIPE:
        { KEY_ADDRESS: 73, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_EXTERNAL_ADDITIONAL_HEATER_START:
        { KEY_ADDRESS: 75, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_CONDENSER_PUMP_LOWEST_ALLOWED_SPEED:
        { KEY_ADDRESS: 76, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_BRINE_PUMP_LOWEST_ALLOWED_SPEED:
        { KEY_ADDRESS: 77, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_EXTERNAL_ADDITIONAL_HEATER_STOP:
        { KEY_ADDRESS: 78, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_CONDENSER_PUMP_HIGHEST_ALLOWED_SPEED:
        { KEY_ADDRESS: 79, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_BRINE_PUMP_HIGHEST_ALLOWED_SPEED:
        { KEY_ADDRESS: 80, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_CONDENSER_PUMP_STANDBY_SPEED:
        { KEY_ADDRESS: 81, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_BRINE_PUMP_STANDBY_SPEED:
        { KEY_ADDRESS: 82, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MINIMUM_ALLOWED_GEAR_IN_POOL:
        { KEY_ADDRESS: 85, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAXIMUM_ALLOWED_GEAR_IN_POOL:
        { KEY_ADDRESS: 86, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MINIMUM_ALLOWED_GEAR_IN_COOLING:
        { KEY_ADDRESS: 87, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAXIMUM_ALLOWED_GEAR_IN_COOLING:
        { KEY_ADDRESS: 88, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_START_TEMP_FOR_COOLING:
        { KEY_ADDRESS: 105, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_STOP_TEMP_FOR_COOLING:
        { KEY_ADDRESS: 106, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_1:
        { KEY_ADDRESS: 107, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_1:
        { KEY_ADDRESS: 108, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_1:
        { KEY_ADDRESS: 109, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_1:
        { KEY_ADDRESS: 110, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_1:
        { KEY_ADDRESS: 111, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_1:
        { KEY_ADDRESS: 112, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_1:
        { KEY_ADDRESS: 113, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_1:
        { KEY_ADDRESS: 114, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_1:
        { KEY_ADDRESS: 115, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_FIXED_SYSTEM_SUPPLY_SET_POINT:
        { KEY_ADDRESS: 116, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_2:
        { KEY_ADDRESS: 199, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_2:
        { KEY_ADDRESS: 200, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_2:
        { KEY_ADDRESS: 201, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_2:
        { KEY_ADDRESS: 202, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_2:
        { KEY_ADDRESS: 203, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_2:
        { KEY_ADDRESS: 204, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_2:
        { KEY_ADDRESS: 205, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_2:
        { KEY_ADDRESS: 206, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_2:
        { KEY_ADDRESS: 207, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_3:
        { KEY_ADDRESS: 208, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_3:
        { KEY_ADDRESS: 209, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_3:
        { KEY_ADDRESS: 210, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_3:
        { KEY_ADDRESS: 211, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_3:
        { KEY_ADDRESS: 212, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_3:
        { KEY_ADDRESS: 213, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_3:
        { KEY_ADDRESS: 214, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_3:
        { KEY_ADDRESS: 215, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_3:
        { KEY_ADDRESS: 216, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_4:
        { KEY_ADDRESS: 239, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_4:
        { KEY_ADDRESS: 240, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_4:
        { KEY_ADDRESS: 241, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_4:
        { KEY_ADDRESS: 242, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_4:
        { KEY_ADDRESS: 243, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_4:
        { KEY_ADDRESS: 244, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_4:
        { KEY_ADDRESS: 245, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_4:
        { KEY_ADDRESS: 246, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_4:
        { KEY_ADDRESS: 247, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MIN_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_5:
        { KEY_ADDRESS: 248, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_MAX_LIMITATION_SET_POINT_CURVE_RADIATOR_MIX_VALVE_5:
        { KEY_ADDRESS: 249, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_1_MIX_VALVE_5:
        { KEY_ADDRESS: 250, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_2_MIX_VALVE_5:
        { KEY_ADDRESS: 251, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_3_MIX_VALVE_5:
        { KEY_ADDRESS: 252, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_4_MIX_VALVE_5:
        { KEY_ADDRESS: 253, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_5_MIX_VALVE_5:
        { KEY_ADDRESS: 254, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_6_MIX_VALVE_5:
        { KEY_ADDRESS: 255, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_CURVE_Y_COORDINATE_7_MIX_VALVE_5:
        { KEY_ADDRESS: 256, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_RETURN_TEMP_FROM_POOL_TO_HEAT_EXCHANGER:
        { KEY_ADDRESS: 299, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 10, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_POOL_HYSTERESIS:
        { KEY_ADDRESS: 300, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 10, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_FOR_SUPPLY_LINE_TEMP_PASSIVE_COOLING_WITH_MIXING_VALVE_1:
        { KEY_ADDRESS: 302, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SET_POINT_MINIMUM_OUTDOOR_TEMP_WHEN_COOLING_IS_PERMITTED:
        { KEY_ADDRESS: 303, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_EXTERNAL_HEATER_OUTDOOR_TEMP_LIMIT:
        { KEY_ADDRESS: 304, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: True },
    ATTR_HOLDING_SELECTED_MODE_FOR_MIXING_VALVE_2:
        { KEY_ADDRESS: 305, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_DESIRED_COOLING_TEMPERATURE_SETPOINT_MIXING_VALVE_2:
        { KEY_ADDRESS: 306, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SEASONAL_COOLING_TEMPERATURE_OUTDOOR_MIXING_VALVE_2:
        { KEY_ADDRESS: 307, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SEASONAL_HEATING_TEMPERATURE_OUTDOOR_MIXING_VALVE_2:
        { KEY_ADDRESS: 308, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SELECTED_MODE_FOR_MIXING_VALVE_3:
        { KEY_ADDRESS: 309, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_DESIRED_COOLING_TEMPERATURE_SETPOINT_MIXING_VALVE_3:
        { KEY_ADDRESS: 310, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SEASONAL_COOLING_TEMPERATURE_OUTDOOR_MIXING_VALVE_3:
        { KEY_ADDRESS: 311, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SEASONAL_HEATING_TEMPERATURE_OUTDOOR_MIXING_VALVE_3:
        { KEY_ADDRESS: 312, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SELECTED_MODE_FOR_MIXING_VALVE_4:
        { KEY_ADDRESS: 313, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_DESIRED_COOLING_TEMPERATURE_SETPOINT_MIXING_VALVE_4:
        { KEY_ADDRESS: 314, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SEASONAL_COOLING_TEMPERATURE_OUTDOOR_MIXING_VALVE_4:
        { KEY_ADDRESS: 315, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SEASONAL_HEATING_TEMPERATURE_OUTDOOR_TEMP_MIXING_VALVE_4:
        { KEY_ADDRESS: 316, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SELECTED_MODE_FOR_MIXING_VALVE_5:
        { KEY_ADDRESS: 317, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 1, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_DESIRED_COOLING_TEMPERATURE_SETPOINT_MIXING_VALVE_5:
        { KEY_ADDRESS: 318, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SEASONAL_COOLING_TEMPERATURE_OUTDOOR_MIXING_VALVE_5:
        { KEY_ADDRESS: 319, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
    ATTR_HOLDING_SEASONAL_HEATING_TEMPERATURE_OUTDOOR_MIXING_VALVE_5:
        { KEY_ADDRESS: 320, KEY_REG_TYPE: REG_HOLDING, KEY_SCALE: 100, KEY_DATATYPE: TYPE_INT, MODEL_MEGA: True, MODEL_INVERTER: False },
}
